<?php
namespace Controllers;

use Doctrine\ORM\EntityManager;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DataSource\ParameterBag;
use Zeedhi\Framework\DataSource\FilterCriteria;
use Zeedhi\Framework\Controller;
use Zeedhi\Framework\Controller\Crud;
use Zeedhi\Framework\DataSource;
use Zeedhi\Framework\DTO\Response\Notification;
use \Zeedhi\Framework\DB\StoredProcedure\StoredProcedure;
use \Zeedhi\Framework\DB\StoredProcedure\Param;
use Exception;

class Gop00240PreparacaoDoOrcamento extends \Teknisa\GER\Controllers\TeknisaCrud
{
    
    protected $dataSourceName = 'lista';
    protected $crudService;
    protected $parameterBag;
    protected $dataSourceManager;
    protected $novoCodigo;
    protected $entityManager;
    protected $connection;
    
    
    public function __construct($crudService, $parameterBag, $dataSourceManager, $entityManager, $novoCodigo, $environment, $connection)
    {
        $this->crudService       = $crudService;
        $this->parameterBag      = $parameterBag;
        $this->dataSourceManager = $dataSourceManager;
        $this->entityManager     = $entityManager;
        $this->novoCodigo        = $novoCodigo;
        $this->environment       = $environment;
        $this->connection        = $connection;
    }
    
    public function getDados(DTO\Request\Row $request, DTO\Response $response)
    {
        
        $row          = $request->getRow();
        $nrOrg        = $this->environment->getNrOrgTrab();
        $currentTime  = $this->environment->getCurrentTime()->format("d/m/Y H:i:s");
        $nrListaFil   = $this->novoCodigo->getCodeByTableName('LISTA', $this->environment->getNrOrgTrab());
        $nrListaOper  = $this->novoCodigo->getCodeByTableName('LISTA', $this->environment->getNrOrgTrab());
        $cdOperLogado = $this->environment->getCdOperador();

        foreach ($row['CDFILIAL'] as $cdfilial) {
            $lista                   = array();
            $lista["NRLISTA"]        = $nrListaFil;
            $lista["CDLISTA"]        = $cdfilial;
            $lista["__is_new"]       = true;
            $lista["DTULTATULIST"]   = $currentTime;
            $lista["DTINCLUSAO"]     = $currentTime;
            $lista["DTULTATU"]       = "";
            $lista["NRORGINCLUSAO"]  = $nrOrg;
            $lista["CDOPERINCLUSAO"] = "";
            $lista["NRORGULTATU"]    = "";
            $lista["CDOPERULTATU"]   = "";
            $lista["IDATIVO"]        = "";
            $lista["NRORG"]          = $nrOrg;
            $lista["IDATIVO"]        = 'S';
            
            $rowsToSave[] = $lista;
            
        }
        $this->crudService->save($this->dataSourceName, $rowsToSave);
        
        foreach ($row['CDOPERADOR'] as $cdOperador) {
            
            $lista                   = array();
            $lista["NRLISTA"]        = $nrListaOper;
            $lista["CDLISTA"]        = $cdOperador;
            $lista["__is_new"]       = true;
            $lista["DTULTATULIST"]   = $currentTime;
            $lista["DTINCLUSAO"]     = $currentTime;
            $lista["DTULTATU"]       = "";
            $lista["NRORGINCLUSAO"]  = $nrOrg;
            $lista["CDOPERINCLUSAO"] = "";
            $lista["NRORGULTATU"]    = "";
            $lista["CDOPERULTATU"]   = "";
            $lista["IDATIVO"]        = "";
            $lista["NRORG"]          = $nrOrg;
            $lista["IDATIVO"]        = 'S';
            
            $rowsToSalvar[] = $lista;
            
        }
        $this->crudService->save($this->dataSourceName, $rowsToSalvar);
    
        $ano             = $row['DTANO'];
        $numPeriodo      = $row['VALUE_PERIOD'];
        $nrListaOperador = $nrListaOper;
        $nrListaUnidade  = $nrListaFil;
        $idExclui        = $row['IDEXCLUIR'];
        $listaOper       = 'S';
        $listaFilial     = 'S';
        $orcadeta        = 'S';
        $itemorca        = $row['stringTpOrca'];
        
        try{
            
            $this->PREPARA_ORCAMENTO($ano, $numPeriodo, $nrListaOperador, $nrListaUnidade, $idExclui, $listaOper, $listaFilial, $orcadeta, $itemorca, $cdOperLogado);
            
            $naoGerados = array();
            $i = sizeof($row['CDFILIAL']);
            for ($x = 0; $i > $x; $i--){
                array_push($naoGerados, $this->naoGerados($row, $row['CDFILIAL'][$i-1]));
            }
            
            if($naoGerados){
                $erroList = array();
                foreach ($naoGerados as $values) {
                    foreach($values as $value){
                        array_push($erroList, "Unidade: ".$value['CDFILIAL']." - ".$value['NMFILIAL']."\nDescrição: ".$value['DSMOTIVO']."\n");
                    }
                }
                unset($value);
                $response->addDataSet(new DataSet("errorList", $erroList));
            }

        }catch(\Exception $ex){
            $response->setError(new Error("Nao foi possivel processar os dados enviados --- " . $ex->getMessage(), 500));
        }
    }
    
    
    public function PREPARA_ORCAMENTO($ano, $numPeriodo, $nrListaOperador, $nrListaUnidade, $idExclui, $listaOper, $listaFilial, $orcadeta, $itemorca, $cdOperLogado)
    {
        $procedure = new StoredProcedure($this->connection, 'PREPARA_ORCAMENTO');
        $procedure->addParam(new Param('P_NRANOORCAOP', Param::PARAM_INPUT, $ano, Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDVERSORCAOP', Param::PARAM_INPUT, $numPeriodo, Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDOPERADOR', Param::PARAM_INPUT, $nrListaOperador, Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDFILIAL', Param::PARAM_INPUT, $nrListaUnidade, Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_IDEXCLUI', Param::PARAM_INPUT, $idExclui, Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_LISTAOPER', Param::PARAM_INPUT, $listaOper, Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_LISTAFIL', Param::PARAM_INPUT, $listaFilial, Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_ORCADETA', Param::PARAM_INPUT, $orcadeta, Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_ITEMORCA', Param::PARAM_INPUT, $itemorca, Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDOPERLOGADO', Param::PARAM_INPUT, $cdOperLogado, Param::PARAM_TYPE_STR));
        //var_dump($procedure->getParams()).die();
    
        $procedure->execute();
     
    }
    
    public function naoGerados($row, $cdfilial){
        $parametros =  array(
                            'P_CDFILIAL' =>  $cdfilial,
                            'P_NRANOORCAGOP' => $row['DTANO'],
                            'P_IDPERIODOORCA'=> $row['IDPERIODOORCA'],
                            'P_NRPERIODOORCA'=> $row['VALUE_PERIOD']
                        );
        $stmt = $this->connection->prepare("SELECT L.*, F.NMFILIAL FROM LOGPREPARAORCAGOP L, FILIAL F
             WHERE
               L.CDFILIAL = F.CDFILIAL AND
               L.NRANOORCAGOP = :P_NRANOORCAGOP AND
               L.IDPERIODOORCA = :P_IDPERIODOORCA AND
               L.NRPERIODOORCA = :P_NRPERIODOORCA AND
               L.CDFILIAL   = :P_CDFILIAL"
               ); 
        $stmt->execute($parametros);
        
        $result = $stmt->fetchAll();
        
		return  $result;
    }

}